<!--
- SPDX-License-Identifier: Apache-2.0
- Copyright (C) 2024 Jayesh Badwaik <jayesh@ambhora.com>
-->

# pykosha

kosha is a workflow description language and pykosha is a reference
implementation of the kosha language in Python.
